==> insanichess_sdk-0.1.4.tar.gz: lib/src/models/settings/game/game.dart <==
import 'package:flutter/foundation.dart';

/// Model for game settings.
class InsanichessGameSettings {
  /// Is undoing / takeback allowed?
  final bool allowUndo;

  /// Should pawns automatically be promoted to queen?
  final bool alwaysPromoteToQueen;

  /// Constructs new `InsanichessGameSettings` object with [allowUndo] and
  /// [alwaysPromoteToQueen].
  const InsanichessGameSettings({
    required this.allowUndo,
    required this.alwaysPromoteToQueen,
  });

  /// Constructs new `InsanichessGameSettings` object with default values.
  const InsanichessGameSettings.defaults()
      : allowUndo = true,
        alwaysPromoteToQueen = false;

  /// Constructs new `InsanichessGameSettings` object from [json].
  InsanichessGameSettings.fromJson(Map<String, dynamic> json)
      : allowUndo = json[InsanichessGameSettingsJsonKey.allowUndo],
        alwaysPromoteToQueen =
            json[InsanichessGameSettingsJsonKey.alwaysPromoteToQueen];

  /// Converts this object to json representation.
  @mustCallSuper
  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      InsanichessGameSettingsJsonKey.allowUndo: allowUndo,
      InsanichessGameSettingsJsonKey.alwaysPromoteToQueen: alwaysPromoteToQueen,
    };
  }
}

/// Keys used in `InsanichessOtbSettings` json representations.
abstract class InsanichessGameSettingsJsonKey {
  /// Key for `InsanichessGameSettings.allowUndo`.
  static const String allowUndo = 'allow_undo';

  /// Key for `InsanichessGameSettings.alwaysPromoteToQueen`.
  static const String alwaysPromoteToQueen = 'always_promote_to_queen';
}

==> insanichess_sdk-0.1.5.tar.gz: lib/src/models/settings/game/game.dart <==
import 'package:flutter/foundation.dart';

import '../../../util/enum/auto_zoom_out_on_move_behaviour.dart';

/// Model for game settings.
class InsanichessGameSettings {
  /// Is undoing / takeback allowed?
  final bool allowUndo;

  /// Should pawns automatically be promoted to queen?
  final bool alwaysPromoteToQueen;

  /// Should the board be zoomed out automatically on move, and if yes, how.
  final AutoZoomOutOnMoveBehaviour autoZoomOutOnMove;

  /// Constructs new `InsanichessGameSettings` object with [allowUndo] and
  /// [alwaysPromoteToQueen].
  const InsanichessGameSettings({
    required this.allowUndo,
    required this.alwaysPromoteToQueen,
    required this.autoZoomOutOnMove,
  });

  /// Constructs new `InsanichessGameSettings` object with default values.
  const InsanichessGameSettings.defaults()
      : allowUndo = true,
        alwaysPromoteToQueen = false,
        autoZoomOutOnMove = AutoZoomOutOnMoveBehaviour.always;

  /// Constructs new `InsanichessGameSettings` object from [json].
  InsanichessGameSettings.fromJson(Map<String, dynamic> json)
      : allowUndo = json[InsanichessGameSettingsJsonKey.allowUndo],
        alwaysPromoteToQueen =
            json[InsanichessGameSettingsJsonKey.alwaysPromoteToQueen],
        autoZoomOutOnMove = autoZoomOutOnMoveBehaviourFromJson(
            json[InsanichessGameSettingsJsonKey.autoZoomOutOnMove]);

  /// Converts this object to json representation.
  @mustCallSuper
  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      InsanichessGameSettingsJsonKey.allowUndo: allowUndo,
      InsanichessGameSettingsJsonKey.alwaysPromoteToQueen: alwaysPromoteToQueen,
      InsanichessGameSettingsJsonKey.autoZoomOutOnMove:
          autoZoomOutOnMove.toJson(),
    };
  }
}

/// Keys used in `InsanichessOtbSettings` json representations.
abstract class InsanichessGameSettingsJsonKey {
  /// Key for `InsanichessGameSettings.allowUndo`.
  static const String allowUndo = 'allow_undo';

  /// Key for `InsanichessGameSettings.alwaysPromoteToQueen`.
  static const String alwaysPromoteToQueen = 'always_promote_to_queen';

  /// Key for `InsanichessSettings.autoZoomOutOnMove`.
  static const String autoZoomOutOnMove = 'auto_zoom_out_on_move';
}
